/* $Id: core.h,v 1.5 2004/04/29 23:32:18 jonas Exp $ */

#ifndef EL__SCRIPTING_GUILE_CORE_H
#define EL__SCRIPTING_GUILE_CORE_H

#ifdef CONFIG_GUILE

#include "modules/module.h"

extern struct module guile_scripting_module;

#endif

#endif
